==> jc-1.4.0.tar.gz: jas/RuntimeConstants.h <==
// public abstract interface jas.RuntimeConstants

// class file dependencies
// @dep_class 8e504cf348adc799 jas_RuntimeConstants
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_RuntimeConstants_H_
#define _JC_jas_RuntimeConstants_H_

// Typedefs
typedef struct _jc_jas_RuntimeConstants$fields_struct	_jc_jas_RuntimeConstants$fields_struct;
typedef const struct _jc_jas_RuntimeConstants$vtype	_jc_jas_RuntimeConstants$vtype;

// Class fields structure
struct _jc_jas_RuntimeConstants$fields_struct {
	_jc_int_array	*opcLengths;
	_jc_object_array	*opcNames;
	jint	ACC__5fABSTRACT;
	jint	ACC__5fFINAL;
	jint	ACC__5fINTERFACE;
	jint	ACC__5fNATIVE;
	jint	ACC__5fPRIVATE;
	jint	ACC__5fPROTECTED;
	jint	ACC__5fPUBLIC;
	jint	ACC__5fSTATIC;
	jint	ACC__5fSUPER;
	jint	ACC__5fSYNCHRONIZED;
	jint	ACC__5fTRANSIENT;
	jint	ACC__5fVOLATILE;
	jint	CONSTANT__5fCLASS;
	jint	CONSTANT__5fDOUBLE;
	jint	CONSTANT__5fFIELD;
	jint	CONSTANT__5fFLOAT;
	jint	CONSTANT__5fINTEGER;
	jint	CONSTANT__5fINTERFACEMETHOD;
	jint	CONSTANT__5fLONG;
	jint	CONSTANT__5fMETHOD;
	jint	CONSTANT__5fNAMEANDTYPE;
	jint	CONSTANT__5fSTRING;
	jint	CONSTANT__5fUNICODE;
	jint	CONSTANT__5fUTF8;
	jint	JAVA__5fMAGIC;
	jint	JAVA__5fMINOR__5fVERSION;
	jint	JAVA__5fVERSION;
	jint	T__5fBOOLEAN;
	jint	T__5fBYTE;
	jint	T__5fCHAR;
	jint	T__5fCLASS;
	jint	T__5fDOUBLE;
	jint	T__5fFLOAT;
	jint	T__5fINT;
	jint	T__5fLONG;
	jint	T__5fSHORT;
	jint	opc__5faaload;
	jint	opc__5faastore;
	jint	opc__5faconst__5fnull;
	jint	opc__5faload;
	jint	opc__5faload__5f0;
	jint	opc__5faload__5f1;
	jint	opc__5faload__5f2;
	jint	opc__5faload__5f3;
	jint	opc__5fanewarray;
	jint	opc__5fareturn;
	jint	opc__5farraylength;
	jint	opc__5fastore;
	jint	opc__5fastore__5f0;
	jint	opc__5fastore__5f1;
	jint	opc__5fastore__5f2;
	jint	opc__5fastore__5f3;
	jint	opc__5fathrow;
	jint	opc__5fbaload;
	jint	opc__5fbastore;
	jint	opc__5fbipush;
	jint	opc__5fbreakpoint;
	jint	opc__5fcaload;
	jint	opc__5fcastore;
	jint	opc__5fcheckcast;
	jint	opc__5fd2f;
	jint	opc__5fd2i;
	jint	opc__5fd2l;
	jint	opc__5fdadd;
	jint	opc__5fdaload;
	jint	opc__5fdastore;
	jint	opc__5fdcmpg;
	jint	opc__5fdcmpl;
	jint	opc__5fdconst__5f0;
	jint	opc__5fdconst__5f1;
	jint	opc__5fddiv;
	jint	opc__5fdead;
	jint	opc__5fdload;
	jint	opc__5fdload__5f0;
	jint	opc__5fdload__5f1;
	jint	opc__5fdload__5f2;
	jint	opc__5fdload__5f3;
	jint	opc__5fdmul;
	jint	opc__5fdneg;
	jint	opc__5fdrem;
	jint	opc__5fdreturn;
	jint	opc__5fdstore;
	jint	opc__5fdstore__5f0;
	jint	opc__5fdstore__5f1;
	jint	opc__5fdstore__5f2;
	jint	opc__5fdstore__5f3;
	jint	opc__5fdsub;
	jint	opc__5fdup;
	jint	opc__5fdup2;
	jint	opc__5fdup2__5fx1;
	jint	opc__5fdup2__5fx2;
	jint	opc__5fdup__5fx1;
	jint	opc__5fdup__5fx2;
	jint	opc__5ff2d;
	jint	opc__5ff2i;
	jint	opc__5ff2l;
	jint	opc__5ffadd;
	jint	opc__5ffaload;
	jint	opc__5ffastore;
	jint	opc__5ffcmpg;
	jint	opc__5ffcmpl;
	jint	opc__5ffconst__5f0;
	jint	opc__5ffconst__5f1;
	jint	opc__5ffconst__5f2;
	jint	opc__5ffdiv;
	jint	opc__5ffload;
	jint	opc__5ffload__5f0;
	jint	opc__5ffload__5f1;
	jint	opc__5ffload__5f2;
	jint	opc__5ffload__5f3;
	jint	opc__5ffmul;
	jint	opc__5ffneg;
	jint	opc__5ffrem;
	jint	opc__5ffreturn;
	jint	opc__5ffstore;
	jint	opc__5ffstore__5f0;
	jint	opc__5ffstore__5f1;
	jint	opc__5ffstore__5f2;
	jint	opc__5ffstore__5f3;
	jint	opc__5ffsub;
	jint	opc__5fgetfield;
	jint	opc__5fgetstatic;
	jint	opc__5fgoto;
	jint	opc__5fgoto__5fw;
	jint	opc__5fi2b;
	jint	opc__5fi2c;
	jint	opc__5fi2d;
	jint	opc__5fi2f;
	jint	opc__5fi2l;
	jint	opc__5fi2s;
	jint	opc__5fiadd;
	jint	opc__5fiaload;
	jint	opc__5fiand;
	jint	opc__5fiastore;
	jint	opc__5ficonst__5f0;
	jint	opc__5ficonst__5f1;
	jint	opc__5ficonst__5f2;
	jint	opc__5ficonst__5f3;
	jint	opc__5ficonst__5f4;
	jint	opc__5ficonst__5f5;
	jint	opc__5ficonst__5fm1;
	jint	opc__5fidiv;
	jint	opc__5fif__5facmpeq;
	jint	opc__5fif__5facmpne;
	jint	opc__5fif__5ficmpeq;
	jint	opc__5fif__5ficmpge;
	jint	opc__5fif__5ficmpgt;
	jint	opc__5fif__5ficmple;
	jint	opc__5fif__5ficmplt;
	jint	opc__5fif__5ficmpne;
	jint	opc__5fifeq;
	jint	opc__5fifge;
	jint	opc__5fifgt;
	jint	opc__5fifle;
	jint	opc__5fiflt;
	jint	opc__5fifne;
	jint	opc__5fifnonnull;
	jint	opc__5fifnull;
	jint	opc__5fiinc;
	jint	opc__5fiload;
	jint	opc__5fiload__5f0;
	jint	opc__5fiload__5f1;
	jint	opc__5fiload__5f2;
	jint	opc__5fiload__5f3;
	jint	opc__5fimul;
	jint	opc__5fineg;
	jint	opc__5finstanceof;
	jint	opc__5fint2byte;
	jint	opc__5fint2char;
	jint	opc__5fint2short;
	jint	opc__5finvokeinterface;
	jint	opc__5finvokenonvirtual;
	jint	opc__5finvokespecial;
	jint	opc__5finvokestatic;
	jint	opc__5finvokevirtual;
	jint	opc__5fior;
	jint	opc__5firem;
	jint	opc__5fireturn;
	jint	opc__5fishl;
	jint	opc__5fishr;
	jint	opc__5fistore;
	jint	opc__5fistore__5f0;
	jint	opc__5fistore__5f1;
	jint	opc__5fistore__5f2;
	jint	opc__5fistore__5f3;
	jint	opc__5fisub;
	jint	opc__5fiushr;
	jint	opc__5fixor;
	jint	opc__5fjsr;
	jint	opc__5fjsr__5fw;
	jint	opc__5fl2d;
	jint	opc__5fl2f;
	jint	opc__5fl2i;
	jint	opc__5flabel;
	jint	opc__5fladd;
	jint	opc__5flaload;
	jint	opc__5fland;
	jint	opc__5flastore;
	jint	opc__5flcmp;
	jint	opc__5flconst__5f0;
	jint	opc__5flconst__5f1;
	jint	opc__5fldc;
	jint	opc__5fldc2__5fw;
	jint	opc__5fldc__5fw;
	jint	opc__5fldiv;
	jint	opc__5flload;
	jint	opc__5flload__5f0;
	jint	opc__5flload__5f1;
	jint	opc__5flload__5f2;
	jint	opc__5flload__5f3;
	jint	opc__5flmul;
	jint	opc__5flneg;
	jint	opc__5flookupswitch;
	jint	opc__5flor;
	jint	opc__5flrem;
	jint	opc__5flreturn;
	jint	opc__5flshl;
	jint	opc__5flshr;
	jint	opc__5flstore;
	jint	opc__5flstore__5f0;
	jint	opc__5flstore__5f1;
	jint	opc__5flstore__5f2;
	jint	opc__5flstore__5f3;
	jint	opc__5flsub;
	jint	opc__5flushr;
	jint	opc__5flxor;
	jint	opc__5fmonitorenter;
	jint	opc__5fmonitorexit;
	jint	opc__5fmultianewarray;
	jint	opc__5fnew;
	jint	opc__5fnewarray;
	jint	opc__5fnop;
	jint	opc__5fpop;
	jint	opc__5fpop2;
	jint	opc__5fputfield;
	jint	opc__5fputstatic;
	jint	opc__5fret;
	jint	opc__5freturn;
	jint	opc__5fsaload;
	jint	opc__5fsastore;
	jint	opc__5fsipush;
	jint	opc__5fswap;
	jint	opc__5ftableswitch;
	jint	opc__5ftry;
	jint	opc__5fwide;
	jint	opc__5fxxxunusedxxx;
};
extern _jc_jas_RuntimeConstants$fields_struct _jc_jas_RuntimeConstants$class_fields;

// Static methods
extern void _jc_jas_RuntimeConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_jas_RuntimeConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_jas_RuntimeConstants$vtype _jc_jas_RuntimeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_RuntimeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_RuntimeConstants$class_object;

#endif	/* _JC_jas_RuntimeConstants_H_ */

==> jc-1.4.6.tar.gz: jas/RuntimeConstants.h <==
// public abstract interface jas.RuntimeConstants

// class file dependencies
// @dep_class 8e504cf348adc799 jas_RuntimeConstants
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_RuntimeConstants_H_
#define _JC_jas_RuntimeConstants_H_

// Typedefs
typedef struct _jc_jas_RuntimeConstants$fields_struct	_jc_jas_RuntimeConstants$fields_struct;
typedef const struct _jc_jas_RuntimeConstants$vtype	_jc_jas_RuntimeConstants$vtype;

// Class fields structure
struct _jc_jas_RuntimeConstants$fields_struct {
	_jc_int_array	*opcLengths;
	_jc_object_array	*opcNames;
	jint	ACC__5fABSTRACT;
	jint	ACC__5fFINAL;
	jint	ACC__5fINTERFACE;
	jint	ACC__5fNATIVE;
	jint	ACC__5fPRIVATE;
	jint	ACC__5fPROTECTED;
	jint	ACC__5fPUBLIC;
	jint	ACC__5fSTATIC;
	jint	ACC__5fSUPER;
	jint	ACC__5fSYNCHRONIZED;
	jint	ACC__5fTRANSIENT;
	jint	ACC__5fVOLATILE;
	jint	CONSTANT__5fCLASS;
	jint	CONSTANT__5fDOUBLE;
	jint	CONSTANT__5fFIELD;
	jint	CONSTANT__5fFLOAT;
	jint	CONSTANT__5fINTEGER;
	jint	CONSTANT__5fINTERFACEMETHOD;
	jint	CONSTANT__5fLONG;
	jint	CONSTANT__5fMETHOD;
	jint	CONSTANT__5fNAMEANDTYPE;
	jint	CONSTANT__5fSTRING;
	jint	CONSTANT__5fUNICODE;
	jint	CONSTANT__5fUTF8;
	jint	JAVA__5fMAGIC;
	jint	JAVA__5fMINOR__5fVERSION;
	jint	JAVA__5fVERSION;
	jint	T__5fBOOLEAN;
	jint	T__5fBYTE;
	jint	T__5fCHAR;
	jint	T__5fCLASS;
	jint	T__5fDOUBLE;
	jint	T__5fFLOAT;
	jint	T__5fINT;
	jint	T__5fLONG;
	jint	T__5fSHORT;
	jint	opc__5faaload;
	jint	opc__5faastore;
	jint	opc__5faconst__5fnull;
	jint	opc__5faload;
	jint	opc__5faload__5f0;
	jint	opc__5faload__5f1;
	jint	opc__5faload__5f2;
	jint	opc__5faload__5f3;
	jint	opc__5fanewarray;
	jint	opc__5fareturn;
	jint	opc__5farraylength;
	jint	opc__5fastore;
	jint	opc__5fastore__5f0;
	jint	opc__5fastore__5f1;
	jint	opc__5fastore__5f2;
	jint	opc__5fastore__5f3;
	jint	opc__5fathrow;
	jint	opc__5fbaload;
	jint	opc__5fbastore;
	jint	opc__5fbipush;
	jint	opc__5fbreakpoint;
	jint	opc__5fcaload;
	jint	opc__5fcastore;
	jint	opc__5fcheckcast;
	jint	opc__5fd2f;
	jint	opc__5fd2i;
	jint	opc__5fd2l;
	jint	opc__5fdadd;
	jint	opc__5fdaload;
	jint	opc__5fdastore;
	jint	opc__5fdcmpg;
	jint	opc__5fdcmpl;
	jint	opc__5fdconst__5f0;
	jint	opc__5fdconst__5f1;
	jint	opc__5fddiv;
	jint	opc__5fdead;
	jint	opc__5fdload;
	jint	opc__5fdload__5f0;
	jint	opc__5fdload__5f1;
	jint	opc__5fdload__5f2;
	jint	opc__5fdload__5f3;
	jint	opc__5fdmul;
	jint	opc__5fdneg;
	jint	opc__5fdrem;
	jint	opc__5fdreturn;
	jint	opc__5fdstore;
	jint	opc__5fdstore__5f0;
	jint	opc__5fdstore__5f1;
	jint	opc__5fdstore__5f2;
	jint	opc__5fdstore__5f3;
	jint	opc__5fdsub;
	jint	opc__5fdup;
	jint	opc__5fdup2;
	jint	opc__5fdup2__5fx1;
	jint	opc__5fdup2__5fx2;
	jint	opc__5fdup__5fx1;
	jint	opc__5fdup__5fx2;
	jint	opc__5ff2d;
	jint	opc__5ff2i;
	jint	opc__5ff2l;
	jint	opc__5ffadd;
	jint	opc__5ffaload;
	jint	opc__5ffastore;
	jint	opc__5ffcmpg;
	jint	opc__5ffcmpl;
	jint	opc__5ffconst__5f0;
	jint	opc__5ffconst__5f1;
	jint	opc__5ffconst__5f2;
	jint	opc__5ffdiv;
	jint	opc__5ffload;
	jint	opc__5ffload__5f0;
	jint	opc__5ffload__5f1;
	jint	opc__5ffload__5f2;
	jint	opc__5ffload__5f3;
	jint	opc__5ffmul;
	jint	opc__5ffneg;
	jint	opc__5ffrem;
	jint	opc__5ffreturn;
	jint	opc__5ffstore;
	jint	opc__5ffstore__5f0;
	jint	opc__5ffstore__5f1;
	jint	opc__5ffstore__5f2;
	jint	opc__5ffstore__5f3;
	jint	opc__5ffsub;
	jint	opc__5fgetfield;
	jint	opc__5fgetstatic;
	jint	opc__5fgoto;
	jint	opc__5fgoto__5fw;
	jint	opc__5fi2b;
	jint	opc__5fi2c;
	jint	opc__5fi2d;
	jint	opc__5fi2f;
	jint	opc__5fi2l;
	jint	opc__5fi2s;
	jint	opc__5fiadd;
	jint	opc__5fiaload;
	jint	opc__5fiand;
	jint	opc__5fiastore;
	jint	opc__5ficonst__5f0;
	jint	opc__5ficonst__5f1;
	jint	opc__5ficonst__5f2;
	jint	opc__5ficonst__5f3;
	jint	opc__5ficonst__5f4;
	jint	opc__5ficonst__5f5;
	jint	opc__5ficonst__5fm1;
	jint	opc__5fidiv;
	jint	opc__5fif__5facmpeq;
	jint	opc__5fif__5facmpne;
	jint	opc__5fif__5ficmpeq;
	jint	opc__5fif__5ficmpge;
	jint	opc__5fif__5ficmpgt;
	jint	opc__5fif__5ficmple;
	jint	opc__5fif__5ficmplt;
	jint	opc__5fif__5ficmpne;
	jint	opc__5fifeq;
	jint	opc__5fifge;
	jint	opc__5fifgt;
	jint	opc__5fifle;
	jint	opc__5fiflt;
	jint	opc__5fifne;
	jint	opc__5fifnonnull;
	jint	opc__5fifnull;
	jint	opc__5fiinc;
	jint	opc__5fiload;
	jint	opc__5fiload__5f0;
	jint	opc__5fiload__5f1;
	jint	opc__5fiload__5f2;
	jint	opc__5fiload__5f3;
	jint	opc__5fimul;
	jint	opc__5fineg;
	jint	opc__5finstanceof;
	jint	opc__5fint2byte;
	jint	opc__5fint2char;
	jint	opc__5fint2short;
	jint	opc__5finvokeinterface;
	jint	opc__5finvokenonvirtual;
	jint	opc__5finvokespecial;
	jint	opc__5finvokestatic;
	jint	opc__5finvokevirtual;
	jint	opc__5fior;
	jint	opc__5firem;
	jint	opc__5fireturn;
	jint	opc__5fishl;
	jint	opc__5fishr;
	jint	opc__5fistore;
	jint	opc__5fistore__5f0;
	jint	opc__5fistore__5f1;
	jint	opc__5fistore__5f2;
	jint	opc__5fistore__5f3;
	jint	opc__5fisub;
	jint	opc__5fiushr;
	jint	opc__5fixor;
	jint	opc__5fjsr;
	jint	opc__5fjsr__5fw;
	jint	opc__5fl2d;
	jint	opc__5fl2f;
	jint	opc__5fl2i;
	jint	opc__5flabel;
	jint	opc__5fladd;
	jint	opc__5flaload;
	jint	opc__5fland;
	jint	opc__5flastore;
	jint	opc__5flcmp;
	jint	opc__5flconst__5f0;
	jint	opc__5flconst__5f1;
	jint	opc__5fldc;
	jint	opc__5fldc2__5fw;
	jint	opc__5fldc__5fw;
	jint	opc__5fldiv;
	jint	opc__5flload;
	jint	opc__5flload__5f0;
	jint	opc__5flload__5f1;
	jint	opc__5flload__5f2;
	jint	opc__5flload__5f3;
	jint	opc__5flmul;
	jint	opc__5flneg;
	jint	opc__5flookupswitch;
	jint	opc__5flor;
	jint	opc__5flrem;
	jint	opc__5flreturn;
	jint	opc__5flshl;
	jint	opc__5flshr;
	jint	opc__5flstore;
	jint	opc__5flstore__5f0;
	jint	opc__5flstore__5f1;
	jint	opc__5flstore__5f2;
	jint	opc__5flstore__5f3;
	jint	opc__5flsub;
	jint	opc__5flushr;
	jint	opc__5flxor;
	jint	opc__5fmonitorenter;
	jint	opc__5fmonitorexit;
	jint	opc__5fmultianewarray;
	jint	opc__5fnew;
	jint	opc__5fnewarray;
	jint	opc__5fnop;
	jint	opc__5fpop;
	jint	opc__5fpop2;
	jint	opc__5fputfield;
	jint	opc__5fputstatic;
	jint	opc__5fret;
	jint	opc__5freturn;
	jint	opc__5fsaload;
	jint	opc__5fsastore;
	jint	opc__5fsipush;
	jint	opc__5fswap;
	jint	opc__5ftableswitch;
	jint	opc__5ftry;
	jint	opc__5fwide;
	jint	opc__5fxxxunusedxxx;
};
extern _jc_jas_RuntimeConstants$fields_struct _jc_jas_RuntimeConstants$class_fields;

// Static methods
extern void _jc_jas_RuntimeConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_jas_RuntimeConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_jas_RuntimeConstants$vtype _jc_jas_RuntimeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_RuntimeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_RuntimeConstants$class_object;

#endif	/* _JC_jas_RuntimeConstants_H_ */
